==============
pysenal
==============
.. image:: https://img.shields.io/travis/supercoderhawk/pysenal.svg
    :target: https://travis-ci.org/supercoderhawk/pysenal
.. image:: https://img.shields.io/codecov/c/github/supercoderhawk/pysenal.svg
    :target: https://codecov.io/gh/supercoderhawk/pysenal
.. image:: https://img.shields.io/pypi/v/pysenal.svg
    :target: https://pypi.org/project/pysenal
.. image:: https://img.shields.io/pypi/dm/pysenal.svg
    :target: https://pypi.org/project/pysenal

Python useful utilities methods, only for Python3

Description
===========
This project provides many useful utilities method and class for Python3, including io opertions and so on..